# django-trending

django-trending is an app that provides a generic way to capture view counts
of generic objects and keep daily summery totals for purposes of enabling the
display of the most popular (by view count) objects of a certain type (as well
a "kind" within a certain ContentType; e.g. a category or label) over a certain
period of time.